<?php

	lt_include( PLOG_CLASS_PATH."class/plugin/pluginbase.class.php" );
	lt_include( PLOG_CLASS_PATH."plugins/moderate/class/dao/unmoderatedcomments.class.php" );
	
	/**
	 * implements moderation of comments
	 */
	class PluginModerate extends PluginBase
	{
        var $pluginEnabled;		
		
		function PluginModerate($source = "")
		{
			$this->PluginBase($source);
			
			$this->id = "moderate";
			$this->desc = "Provides moderation of comments";
			$this->author = "The LifeType Project";
			$this->locales = Array( "en_UK", "zh_TW", "es_ES", "fr_FR", "ca_ES" );
            $this->version = "20120511";

			if( $source == "admin" )
				$this->initAdmin();
			else
				$this->init();
		}
		
		/**
		 * process the events that we have registered
		 *
		 * @see PluginBase::process
		 * @see PluginManager
		 */
		function process( $eventType, $params )
		{
		    // make sure we're processing the right event!
		    if( $eventType != EVENT_PRE_COMMENT_ADD ) 
		      return true;

            $blogSettings = $this->blogInfo->getSettings();

			// do nothing if the plugin is not enabled!
			if( !$blogSettings->getValue("plugin_moderate_enabled"))
				return true;

            if($blogSettings->getValue("plugin_moderate_bypass_by_auth")){
                    // If this user is logged in, bypass moderation
                if(SessionManager::getUserInfoFromSession())
                    return true;
            }

            $comment = $params["comment"];
            $status = COMMENT_STATUS_UNMODERATED;
            
            $ip = $comment->getClientIp();
                // Only check if this IP is valid
            if($ip){
                if($blogSettings->getValue("plugin_moderate_bypass_by_ip")){
                    lt_include( PLOG_CLASS_PATH."class/database/db.class.php" );
                    $this->db =& Db::getDb();
                    $dbPrefix = Db::getPrefix();

                        // if this ip has previously been used for a validated comment,
                        // don't moderate it
                    $query = "SELECT id FROM ${dbPrefix}articles_comments WHERE ".
                        "blog_id = '".$this->blogInfo->getId()."' AND ".
                        "status = ".COMMENT_STATUS_NONSPAM." AND ".
                        "client_ip = '$ip' LIMIT 1";
                    $result = $this->db->Execute($query);
                    if($result && $result->RecordCount())
                        return true;
                }
                if($blogSettings->getValue("plugin_moderate_mark_repeated_by_ip")){
                    lt_include( PLOG_CLASS_PATH."class/database/db.class.php" );
                    $this->db =& Db::getDb();
                    $dbPrefix = Db::getPrefix();

                        // if this ip has previously been used for multiple comments that haven't been
                        // approved yet, conditionally mark it as spam (based on the user's preferences)
                        // The idea is that normal users won't keep commenting before seeing their
                        // comments published
                    $query = "SELECT id FROM ${dbPrefix}articles_comments WHERE ".
                        "blog_id = '".$this->blogInfo->getId()."' AND ".
                        "status = ".COMMENT_STATUS_UNMODERATED." AND ".
                        "client_ip = '$ip' LIMIT 2";

                    $result = $this->db->Execute($query);
                    if($result && $result->RecordCount() > 1)
                        $status = COMMENT_STATUS_SPAM;
                }
            }
            
                // mark the comment as moderated (default), or according to the
                // preferences/checks above
			$comment->setStatus( $status );
			$params["comment"] = $comment;
		      
			return true;
		}
		
		function init(){			
			$this->registerNotification( EVENT_PRE_COMMENT_ADD );
		}

		function initAdmin(){			
			$this->registerAdminAction( "unmoderatedComments", "AdminUnmoderatedCommentsAction" );
			$this->registerAdminAction( "updateUnmoderatedComment", "AdminUpdateUnmoderatedCommentsAction" );
			$this->registerAdminAction( "updateUnmoderatedComments", "AdminUpdateUnmoderatedCommentsAction" );
			$this->registerAdminAction( "moderatePluginSettings", "AdminModeratePluginSettingsAction" );
			$this->registerAdminAction( "moderatePluginUpdateSettings", "AdminModeratePluginUpdateSettingsAction" );
			
			$this->addMenuEntry( "/menu/Manage/managePosts", "unmoderatedComments",
                                 "admin.php?op=unmoderatedComments", "" );

			$menu =& Menu::getMenu();
            if( !$menu->entryExists( "/menu/controlCenter/manageAntiSpamPlugins" ))                     
                $this->addMenuEntry( "/menu/controlCenter", "manageAntiSpamPlugins", "", ""  );
            $this->addMenuEntry( "/menu/controlCenter/manageAntiSpamPlugins",
                                 "moderatePluginSettings",
                                 "admin.php?op=moderatePluginSettings", "" );
		}

		function register()
		{
		    $blogSettings = $this->blogInfo->getSettings();
			$this->pluginEnabled = $blogSettings->getValue( "plugin_moderate_enabled" );
		}

	    function isEnabled()
	    {
	        return $this->pluginEnabled;
	    }
	
		function getPluginConfigurationKeys()
		{			
			return( Array(
                        Array( "name" => "plugin_moderate_enabled", "type" => "boolean" ),
                        Array( "name" => "plugin_moderate_bypass_by_ip", "type" => "boolean" ),
                        Array( "name" => "plugin_moderate_bypass_by_auth", "type" => "boolean" ),
                        Array( "name" => "plugin_moderate_mark_repeated_by_ip", "type" => "boolean" )
			));
		}	
	}  
